/* Account.c generated by valac 0.56.19, the Vala compiler
 * generated from Account.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <gee.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_ACCOUNT (tuba_widgets_account_get_type ())
#define TUBA_WIDGETS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount))
#define TUBA_WIDGETS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))
#define TUBA_WIDGETS_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))

typedef struct _TubaWidgetsAccount TubaWidgetsAccount;
typedef struct _TubaWidgetsAccountClass TubaWidgetsAccountClass;
typedef struct _TubaWidgetsAccountPrivate TubaWidgetsAccountPrivate;

#define TUBA_WIDGETS_TYPE_BACKGROUND (tuba_widgets_background_get_type ())
#define TUBA_WIDGETS_BACKGROUND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_BACKGROUND, TubaWidgetsBackground))
#define TUBA_WIDGETS_BACKGROUND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_BACKGROUND, TubaWidgetsBackgroundClass))
#define TUBA_WIDGETS_IS_BACKGROUND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_BACKGROUND))
#define TUBA_WIDGETS_IS_BACKGROUND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_BACKGROUND))
#define TUBA_WIDGETS_BACKGROUND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_BACKGROUND, TubaWidgetsBackgroundClass))

typedef struct _TubaWidgetsBackground TubaWidgetsBackground;
typedef struct _TubaWidgetsBackgroundClass TubaWidgetsBackgroundClass;

#define TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS (tuba_widgets_label_with_widgets_get_type ())
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgets))
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgetsClass))
#define TUBA_WIDGETS_IS_LABEL_WITH_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS))
#define TUBA_WIDGETS_IS_LABEL_WITH_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS))
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgetsClass))

typedef struct _TubaWidgetsLabelWithWidgets TubaWidgetsLabelWithWidgets;
typedef struct _TubaWidgetsLabelWithWidgetsClass TubaWidgetsLabelWithWidgetsClass;

#define TUBA_WIDGETS_TYPE_EMOJI_LABEL (tuba_widgets_emoji_label_get_type ())
#define TUBA_WIDGETS_EMOJI_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabel))
#define TUBA_WIDGETS_EMOJI_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabelClass))
#define TUBA_WIDGETS_IS_EMOJI_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL))
#define TUBA_WIDGETS_IS_EMOJI_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_EMOJI_LABEL))
#define TUBA_WIDGETS_EMOJI_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabelClass))

typedef struct _TubaWidgetsEmojiLabel TubaWidgetsEmojiLabel;
typedef struct _TubaWidgetsEmojiLabelClass TubaWidgetsEmojiLabelClass;

#define TUBA_WIDGETS_TYPE_AVATAR (tuba_widgets_avatar_get_type ())
#define TUBA_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatar))
#define TUBA_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))
#define TUBA_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))

typedef struct _TubaWidgetsAvatar TubaWidgetsAvatar;
typedef struct _TubaWidgetsAvatarClass TubaWidgetsAvatarClass;

#define TUBA_WIDGETS_TYPE_MARKUP_VIEW (tuba_widgets_markup_view_get_type ())
#define TUBA_WIDGETS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupView))
#define TUBA_WIDGETS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))
#define TUBA_WIDGETS_IS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_IS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_MARKUP_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))

typedef struct _TubaWidgetsMarkupView TubaWidgetsMarkupView;
typedef struct _TubaWidgetsMarkupViewClass TubaWidgetsMarkupViewClass;

#define TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON (tuba_widgets_relationship_button_get_type ())
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButton))
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButtonClass))
#define TUBA_WIDGETS_IS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_IS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButtonClass))

typedef struct _TubaWidgetsRelationshipButton TubaWidgetsRelationshipButton;
typedef struct _TubaWidgetsRelationshipButtonClass TubaWidgetsRelationshipButtonClass;

#define TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON (tuba_widgets_account_relationship_button_get_type ())
#define TUBA_WIDGETS_ACCOUNT_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsAccountRelationshipButton))
#define TUBA_WIDGETS_ACCOUNT_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsAccountRelationshipButtonClass))
#define TUBA_WIDGETS_ACCOUNT_IS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_ACCOUNT_IS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_ACCOUNT_RELATIONSHIP_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsAccountRelationshipButtonClass))

typedef struct _TubaWidgetsAccountRelationshipButton TubaWidgetsAccountRelationshipButton;
typedef struct _TubaWidgetsAccountRelationshipButtonClass TubaWidgetsAccountRelationshipButtonClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;
enum  {
	TUBA_WIDGETS_ACCOUNT_0_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_DISABLE_PROFILE_OPEN_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_RS_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_ADDITIONAL_LABEL_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_COVER_BADGE_LABEL_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_IS_BOT_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_API_TYPE_SEARCH_RESULT (tuba_api_search_result_get_type ())
#define TUBA_API_SEARCH_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SEARCH_RESULT, TubaAPISearchResult))
#define TUBA_API_IS_SEARCH_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SEARCH_RESULT))
#define TUBA_API_SEARCH_RESULT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_API_TYPE_SEARCH_RESULT, TubaAPISearchResultIface))

typedef struct _TubaAPISearchResult TubaAPISearchResult;
typedef struct _TubaAPISearchResultIface TubaAPISearchResultIface;
typedef void (*TubaHelperImageOnItemChangedFn) (GdkPaintable* data, gpointer user_data);

#define TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW (tuba_widgets_follow_request_row_get_type ())
#define TUBA_WIDGETS_FOLLOW_REQUEST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRow))
#define TUBA_WIDGETS_FOLLOW_REQUEST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRowClass))
#define TUBA_WIDGETS_IS_FOLLOW_REQUEST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW))
#define TUBA_WIDGETS_IS_FOLLOW_REQUEST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW))
#define TUBA_WIDGETS_FOLLOW_REQUEST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRowClass))

typedef struct _TubaWidgetsFollowRequestRow TubaWidgetsFollowRequestRow;
typedef struct _TubaWidgetsFollowRequestRowClass TubaWidgetsFollowRequestRowClass;
typedef struct _TubaWidgetsRelationshipButtonPrivate TubaWidgetsRelationshipButtonPrivate;
typedef struct _TubaWidgetsAccountRelationshipButtonPrivate TubaWidgetsAccountRelationshipButtonPrivate;
enum  {
	TUBA_WIDGETS_ACCOUNT_RELATIONSHIP_BUTTON_0_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_RELATIONSHIP_BUTTON_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_account_relationship_button_properties[TUBA_WIDGETS_ACCOUNT_RELATIONSHIP_BUTTON_NUM_PROPERTIES];

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;
enum  {
	TUBA_WIDGETS_ACCOUNT_OPEN_SIGNAL,
	TUBA_WIDGETS_ACCOUNT_NUM_SIGNALS
};
static guint tuba_widgets_account_signals[TUBA_WIDGETS_ACCOUNT_NUM_SIGNALS] = {0};

struct _TubaWidgetsAccount {
	GtkListBoxRow parent_instance;
	TubaWidgetsAccountPrivate * priv;
};

struct _TubaWidgetsAccountClass {
	GtkListBoxRowClass parent_class;
};

struct _TubaWidgetsAccountPrivate {
	TubaWidgetsBackground* background;
	GtkOverlay* cover_overlay;
	GtkLabel* cover_badge;
	GtkImage* cover_bot_badge;
	GtkBox* cover_badge_box;
	TubaWidgetsEmojiLabel* display_name;
	GtkLabel* handle;
	GtkLabel* stats_label;
	TubaWidgetsAvatar* avatar;
	TubaWidgetsMarkupView* note;
	TubaWidgetsAccountRelationshipButton* rsbtn;
	GtkGrid* grid;
	gulong invalidate_signal_id;
	TubaAPIAccount* _api_account;
	gchar* account_id;
	gulong open_signal;
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaAPISearchResultIface {
	GTypeInterface parent_iface;
	GRegex* (*get_tuba_search_query_regex) (TubaAPISearchResult* self);
	void (*set_tuba_search_query_regex) (TubaAPISearchResult* self, GRegex* value);
};

struct _TubaWidgetsRelationshipButton {
	GtkButton parent_instance;
	TubaWidgetsRelationshipButtonPrivate * priv;
	GSourceFunc fn;
	gpointer fn_target;
	GDestroyNotify fn_target_destroy_notify;
};

struct _TubaWidgetsRelationshipButtonClass {
	GtkButtonClass parent_class;
	void (*invalidate) (TubaWidgetsRelationshipButton* self);
};

struct _TubaWidgetsAccountRelationshipButton {
	TubaWidgetsRelationshipButton parent_instance;
	TubaWidgetsAccountRelationshipButtonPrivate * priv;
};

struct _TubaWidgetsAccountRelationshipButtonClass {
	TubaWidgetsRelationshipButtonClass parent_class;
};

static gint TubaWidgetsAccount_private_offset;
static gpointer tuba_widgets_account_parent_class = NULL;
VALA_EXTERN TubaSettings* tuba_settings;
static gpointer tuba_widgets_account_relationship_button_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;

VALA_EXTERN GType tuba_widgets_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccount, g_object_unref)
VALA_EXTERN GType tuba_widgets_background_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsBackground, g_object_unref)
VALA_EXTERN GType tuba_widgets_label_with_widgets_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsLabelWithWidgets, g_object_unref)
VALA_EXTERN GType tuba_widgets_emoji_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsEmojiLabel, g_object_unref)
VALA_EXTERN GType tuba_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAvatar, g_object_unref)
VALA_EXTERN GType tuba_widgets_markup_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsMarkupView, g_object_unref)
VALA_EXTERN GType tuba_widgets_relationship_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsRelationshipButton, g_object_unref)
VALA_EXTERN GType tuba_widgets_account_relationship_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccountRelationshipButton, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
static void tuba_widgets_account_on_rs_invalidate (TubaWidgetsAccount* self);
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN TubaAPIRelationship* tuba_widgets_relationship_button_get_rs (TubaWidgetsRelationshipButton* self);
VALA_EXTERN gchar* tuba_api_relationship_to_string (TubaAPIRelationship* self);
VALA_EXTERN void tuba_widgets_account_set_cover_badge_label (TubaWidgetsAccount* self,
                                                 const gchar* value);
static void tuba_widgets_account_update_aria (TubaWidgetsAccount* self);
static void tuba_widgets_account_update_cover_badge (TubaWidgetsAccount* self);
VALA_EXTERN gboolean tuba_widgets_account_get_is_bot (TubaWidgetsAccount* self);
static void tuba_widgets_account_toggle_scale_emoji_hover (TubaWidgetsAccount* self);
VALA_EXTERN void tuba_toggle_css (GtkWidget* wdg,
                      gboolean state,
                      const gchar* style);
VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN gboolean tuba_settings_get_scale_emoji_hover (TubaSettings* self);
static void tuba_widgets_account_on_cache_response (TubaWidgetsAccount* self,
                                             GdkPaintable* data);
VALA_EXTERN void tuba_widgets_background_set_paintable (TubaWidgetsBackground* self,
                                            GdkPaintable* value);
VALA_EXTERN const gchar* tuba_widgets_emoji_label_get_content (TubaWidgetsEmojiLabel* self);
VALA_EXTERN const gchar* tuba_widgets_account_get_cover_badge_label (TubaWidgetsAccount* self);
VALA_EXTERN TubaWidgetsAccount* tuba_widgets_account_new (TubaAPIAccount* account);
VALA_EXTERN TubaWidgetsAccount* tuba_widgets_account_construct (GType object_type,
                                                    TubaAPIAccount* account);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
static void _tuba_widgetizable_open_tuba_widgets_account_open (TubaWidgetsAccount* _sender,
                                                        gpointer self);
static void _tuba_widgetizable_open_gtk_button_clicked (GtkButton* _sender,
                                                 gpointer self);
static void _tuba_widgets_account_toggle_scale_emoji_hover_g_object_notify (GObject* _sender,
                                                                     GParamSpec* pspec,
                                                                     gpointer self);
VALA_EXTERN GeeHashMap* tuba_api_account_get_emojis_map (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_emoji_label_set_instance_emojis (TubaWidgetsEmojiLabel* self,
                                                   GeeHashMap* value);
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_emoji_label_set_content (TubaWidgetsEmojiLabel* self,
                                           const gchar* value);
VALA_EXTERN gchar* tuba_api_account_get_handle (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_avatar_set_account (TubaWidgetsAvatar* self,
                                      TubaAPIAccount* value);
VALA_EXTERN const gchar* tuba_api_account_get_avatar_description (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_avatar_set_alternative_text (TubaWidgetsAvatar* self,
                                               const gchar* value);
VALA_EXTERN GType tuba_api_search_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPISearchResult, g_object_unref)
VALA_EXTERN GRegex* tuba_api_search_result_get_tuba_search_query_regex (TubaAPISearchResult* self);
VALA_EXTERN void tuba_widgets_markup_view_set_bold_text_regex (TubaWidgetsMarkupView* self,
                                                   GRegex* value);
VALA_EXTERN void tuba_widgets_markup_view_set_instance_emojis (TubaWidgetsMarkupView* self,
                                                   GeeHashMap* value);
VALA_EXTERN const gchar* tuba_api_account_get_note (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_markup_view_set_content (TubaWidgetsMarkupView* self,
                                           const gchar* value);
VALA_EXTERN gboolean tuba_api_account_get_bot (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_relationship_button_set_handle (TubaWidgetsRelationshipButton* self,
                                                  const gchar* value);
VALA_EXTERN TubaAPIRelationship* tuba_api_account_get_tuba_rs (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_account_set_rs (TubaWidgetsAccount* self,
                                  TubaAPIRelationship* value);
static void tuba_widgets_account_set_api_account (TubaWidgetsAccount* self,
                                           TubaAPIAccount* value);
static TubaAPIAccount* tuba_widgets_account_get_api_account (TubaWidgetsAccount* self);
static void tuba_widgets_account_on_tuba_rs (TubaWidgetsAccount* self);
static void _tuba_widgets_account_on_tuba_rs_g_object_notify (GObject* _sender,
                                                       GParamSpec* pspec,
                                                       gpointer self);
VALA_EXTERN const gchar* tuba_api_account_get_header (TubaAPIAccount* self);
VALA_EXTERN GdkPaintable* tuba_widgets_avatar_get_custom_image (TubaWidgetsAvatar* self);
VALA_EXTERN void tuba_helper_image_request_paintable (const gchar* url,
                                          const gchar* blurhash,
                                          gboolean disable_cache,
                                          TubaHelperImageOnItemChangedFn cb,
                                          gpointer cb_target,
                                          GDestroyNotify cb_target_destroy_notify,
                                          GCancellable* cancellable);
static void _tuba_widgets_account_on_cache_response_tuba_helper_image_on_item_changed_fn (GdkPaintable* data,
                                                                                   gpointer self);
VALA_EXTERN const gchar* tuba_api_account_get_header_description (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_background_set_alternative_text (TubaWidgetsBackground* self,
                                                   const gchar* value);
VALA_EXTERN gint64 tuba_api_account_get_statuses_count (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_utils_units_shorten (gint64 unit);
static void _vala_array_add129 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
VALA_EXTERN gint64 tuba_api_account_get_followers_count (TubaAPIAccount* self);
static void _vala_array_add130 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
VALA_EXTERN gint64 tuba_api_account_get_following_count (TubaAPIAccount* self);
static void _vala_array_add131 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
VALA_EXTERN GType tuba_widgets_follow_request_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsFollowRequestRow, g_object_unref)
VALA_EXTERN TubaWidgetsFollowRequestRow* tuba_widgets_account_add_fr_row (TubaWidgetsAccount* self);
VALA_EXTERN TubaWidgetsFollowRequestRow* tuba_widgets_follow_request_row_new (const gchar* t_id);
VALA_EXTERN TubaWidgetsFollowRequestRow* tuba_widgets_follow_request_row_construct (GType object_type,
                                                                        const gchar* t_id);
VALA_EXTERN void tuba_widgets_account_set_disable_profile_open (TubaWidgetsAccount* self,
                                                    gboolean value);
VALA_EXTERN void tuba_widgets_relationship_button_set_rs (TubaWidgetsRelationshipButton* self,
                                              TubaAPIRelationship* value);
VALA_EXTERN gboolean tuba_api_relationship_get_tuba_has_loaded (TubaAPIRelationship* self);
static void _tuba_widgets_account_on_rs_invalidate_tuba_api_relationship_invalidated (TubaAPIRelationship* _sender,
                                                                               gpointer self);
VALA_EXTERN void tuba_widgets_account_set_additional_label (TubaWidgetsAccount* self,
                                                const gchar* value);
VALA_EXTERN void tuba_widgets_account_set_is_bot (TubaWidgetsAccount* self,
                                      gboolean value);
VALA_EXTERN void tuba_widgets_relationship_button_invalidate (TubaWidgetsRelationshipButton* self);
static void tuba_widgets_account_relationship_button_on_relationship_invalidated_global (TubaWidgetsAccountRelationshipButton* self,
                                                                                  TubaAPIRelationship* new_relationship);
VALA_EXTERN const gchar* tuba_api_relationship_get_id (TubaAPIRelationship* self);
static void tuba_widgets_account_relationship_button_real_invalidate (TubaWidgetsRelationshipButton* base);
VALA_EXTERN gboolean tuba_api_relationship_get_domain_blocking (TubaAPIRelationship* self);
VALA_EXTERN TubaWidgetsAccountRelationshipButton* tuba_widgets_account_relationship_button_new (void);
VALA_EXTERN TubaWidgetsAccountRelationshipButton* tuba_widgets_account_relationship_button_construct (GType object_type);
VALA_EXTERN TubaWidgetsRelationshipButton* tuba_widgets_relationship_button_new (void);
VALA_EXTERN TubaWidgetsRelationshipButton* tuba_widgets_relationship_button_construct (GType object_type);
static GObject * tuba_widgets_account_relationship_button_constructor (GType type,
                                                                guint n_construct_properties,
                                                                GObjectConstructParam * construct_properties);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
static void _tuba_widgets_account_relationship_button_on_relationship_invalidated_global_tuba_application_relationship_invalidated (TubaApplication* _sender,
                                                                                                                             TubaAPIRelationship* new_relationship,
                                                                                                                             gpointer self);
static GType tuba_widgets_account_relationship_button_get_type_once (void);
static void tuba_widgets_account_finalize (GObject * obj);
static GType tuba_widgets_account_get_type_once (void);
static void _vala_tuba_widgets_account_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec);
static void _vala_tuba_widgets_account_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_widgets_account_get_instance_private (TubaWidgetsAccount* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsAccount_private_offset);
}

static void
tuba_widgets_account_on_rs_invalidate (TubaWidgetsAccount* self)
{
	TubaWidgetsAccountRelationshipButton* _tmp0_;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	TubaWidgetsAccountRelationshipButton* _tmp5_;
	TubaAPIRelationship* _tmp6_;
	TubaAPIRelationship* _tmp7_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->rsbtn;
	_tmp1_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) _tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_relationship_to_string (_tmp2_);
	_tmp4_ = _tmp3_;
	tuba_widgets_account_set_cover_badge_label (self, _tmp4_);
	_g_free0 (_tmp4_);
	_tmp5_ = self->priv->rsbtn;
	_tmp6_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) _tmp5_);
	_tmp7_ = _tmp6_;
	g_signal_handler_disconnect ((GObject*) _tmp7_, self->priv->invalidate_signal_id);
	tuba_widgets_account_update_aria (self);
}

static void
tuba_widgets_account_update_cover_badge (TubaWidgetsAccount* self)
{
	gboolean _tmp0_ = FALSE;
	GtkLabel* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GtkBox* _tmp6_;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_;
	gboolean _tmp9_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->cover_badge;
	_tmp2_ = gtk_widget_get_visible ((GtkWidget*) _tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_) {
		_tmp0_ = TRUE;
	} else {
		gboolean _tmp4_;
		gboolean _tmp5_;
		_tmp4_ = tuba_widgets_account_get_is_bot (self);
		_tmp5_ = _tmp4_;
		_tmp0_ = _tmp5_;
	}
	_tmp6_ = self->priv->cover_badge_box;
	gtk_widget_set_visible ((GtkWidget*) _tmp6_, _tmp0_);
	_tmp8_ = tuba_widgets_account_get_is_bot (self);
	_tmp9_ = _tmp8_;
	if (_tmp9_) {
		GtkLabel* _tmp10_;
		gboolean _tmp11_;
		gboolean _tmp12_;
		_tmp10_ = self->priv->cover_badge;
		_tmp11_ = gtk_widget_get_visible ((GtkWidget*) _tmp10_);
		_tmp12_ = _tmp11_;
		_tmp7_ = !_tmp12_;
	} else {
		_tmp7_ = FALSE;
	}
	if (_tmp7_) {
		GtkBox* _tmp13_;
		_tmp13_ = self->priv->cover_badge_box;
		gtk_widget_add_css_class ((GtkWidget*) _tmp13_, "only-icon");
	} else {
		GtkBox* _tmp14_;
		_tmp14_ = self->priv->cover_badge_box;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp14_, "only-icon");
	}
}

static void
tuba_widgets_account_toggle_scale_emoji_hover (TubaWidgetsAccount* self)
{
	TubaWidgetsMarkupView* _tmp0_;
	TubaSettings* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->note;
	_tmp1_ = tuba_settings;
	_tmp2_ = tuba_settings_get_scale_emoji_hover (_tmp1_);
	_tmp3_ = _tmp2_;
	tuba_toggle_css ((GtkWidget*) _tmp0_, _tmp3_, "lww-scale-emoji-hover");
}

static void
tuba_widgets_account_on_cache_response (TubaWidgetsAccount* self,
                                        GdkPaintable* data)
{
	TubaWidgetsBackground* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->background;
	tuba_widgets_background_set_paintable (_tmp0_, data);
}

static void
tuba_widgets_account_update_aria (TubaWidgetsAccount* self)
{
	gchar* aria_profile = NULL;
	TubaWidgetsEmojiLabel* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GtkLabel* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* aria_relationship = NULL;
	gchar* _tmp7_;
	gboolean _tmp8_ = FALSE;
	GtkLabel* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	gchar* final_aria = NULL;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	GtkLabel* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->display_name;
	_tmp1_ = tuba_widgets_emoji_label_get_content (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = self->priv->handle;
	_tmp4_ = gtk_label_get_label (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = g_strdup_printf (_ ("%s (%s)'s profile."), _tmp2_, _tmp5_);
	aria_profile = _tmp6_;
	_tmp7_ = g_strdup ("");
	aria_relationship = _tmp7_;
	_tmp9_ = self->priv->cover_badge;
	_tmp10_ = gtk_widget_get_visible ((GtkWidget*) _tmp9_);
	_tmp11_ = _tmp10_;
	if (_tmp11_) {
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		_tmp12_ = tuba_widgets_account_get_cover_badge_label (self);
		_tmp13_ = _tmp12_;
		_tmp8_ = g_strcmp0 (_tmp13_, "") != 0;
	} else {
		_tmp8_ = FALSE;
	}
	if (_tmp8_) {
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		_tmp14_ = tuba_widgets_account_get_cover_badge_label (self);
		_tmp15_ = _tmp14_;
		_tmp16_ = g_strdup_printf (_ ("Relationship: %s."), _tmp15_);
		_g_free0 (aria_relationship);
		aria_relationship = _tmp16_;
	}
	_tmp17_ = aria_profile;
	_tmp18_ = aria_relationship;
	_tmp19_ = self->priv->stats_label;
	_tmp20_ = gtk_label_get_text (_tmp19_);
	_tmp21_ = g_strdup_printf ("%s %s %s.", _tmp17_, _tmp18_, _tmp20_);
	final_aria = _tmp21_;
	gtk_accessible_update_property ((GtkAccessible*) self, GTK_ACCESSIBLE_PROPERTY_LABEL, final_aria, -1, -1);
	_g_free0 (final_aria);
	_g_free0 (aria_relationship);
	_g_free0 (aria_profile);
}

static void
_tuba_widgetizable_open_tuba_widgets_account_open (TubaWidgetsAccount* _sender,
                                                   gpointer self)
{
	tuba_widgetizable_open ((TubaWidgetizable*) self);
}

static void
_tuba_widgetizable_open_gtk_button_clicked (GtkButton* _sender,
                                            gpointer self)
{
	tuba_widgetizable_open ((TubaWidgetizable*) self);
}

static void
_tuba_widgets_account_toggle_scale_emoji_hover_g_object_notify (GObject* _sender,
                                                                GParamSpec* pspec,
                                                                gpointer self)
{
	tuba_widgets_account_toggle_scale_emoji_hover ((TubaWidgetsAccount*) self);
}

static void
_tuba_widgets_account_on_tuba_rs_g_object_notify (GObject* _sender,
                                                  GParamSpec* pspec,
                                                  gpointer self)
{
	tuba_widgets_account_on_tuba_rs ((TubaWidgetsAccount*) self);
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

static void
_tuba_widgets_account_on_cache_response_tuba_helper_image_on_item_changed_fn (GdkPaintable* data,
                                                                              gpointer self)
{
	tuba_widgets_account_on_cache_response ((TubaWidgetsAccount*) self, data);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
_vala_array_add129 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add130 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add131 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static gchar*
_vala_g_strjoinv (const gchar* separator,
                  gchar** str_array,
                  gint str_array_length1)
{
	gboolean _tmp0_ = FALSE;
	gchar* result;
	if (separator == NULL) {
		separator = "";
	}
	if (str_array != NULL) {
		gboolean _tmp1_ = FALSE;
		if (str_array_length1 > 0) {
			_tmp1_ = TRUE;
		} else {
			gboolean _tmp2_ = FALSE;
			if (str_array_length1 == -1) {
				const gchar* _tmp3_;
				_tmp3_ = str_array[0];
				_tmp2_ = _tmp3_ != NULL;
			} else {
				_tmp2_ = FALSE;
			}
			_tmp1_ = _tmp2_;
		}
		_tmp0_ = _tmp1_;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gint i = 0;
		gsize len = 0UL;
		gint _tmp16_;
		gint _tmp17_;
		const gchar* res = NULL;
		void* _tmp18_;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_;
		void* ptr = NULL;
		const gchar* _tmp22_;
		void* _tmp23_;
		const gchar* _tmp33_;
		len = (gsize) 1;
		{
			gboolean _tmp4_ = FALSE;
			i = 0;
			_tmp4_ = TRUE;
			while (TRUE) {
				gboolean _tmp6_ = FALSE;
				gboolean _tmp7_ = FALSE;
				gint _tmp10_ = 0;
				const gchar* _tmp11_;
				if (!_tmp4_) {
					gint _tmp5_;
					_tmp5_ = i;
					i = _tmp5_ + 1;
				}
				_tmp4_ = FALSE;
				if (str_array_length1 != -1) {
					_tmp7_ = i < str_array_length1;
				} else {
					_tmp7_ = FALSE;
				}
				if (_tmp7_) {
					_tmp6_ = TRUE;
				} else {
					gboolean _tmp8_ = FALSE;
					if (str_array_length1 == -1) {
						const gchar* _tmp9_;
						_tmp9_ = str_array[i];
						_tmp8_ = _tmp9_ != NULL;
					} else {
						_tmp8_ = FALSE;
					}
					_tmp6_ = _tmp8_;
				}
				if (!_tmp6_) {
					break;
				}
				_tmp11_ = str_array[i];
				if (_tmp11_ != NULL) {
					const gchar* _tmp12_;
					gint _tmp13_;
					gint _tmp14_;
					_tmp12_ = str_array[i];
					_tmp13_ = strlen ((const gchar*) _tmp12_);
					_tmp14_ = _tmp13_;
					_tmp10_ = _tmp14_;
				} else {
					_tmp10_ = 0;
				}
				len += (gsize) _tmp10_;
			}
		}
		if (i == 0) {
			gchar* _tmp15_;
			_tmp15_ = g_strdup ("");
			result = _tmp15_;
			return result;
		}
		str_array_length1 = i;
		_tmp16_ = strlen ((const gchar*) separator);
		_tmp17_ = _tmp16_;
		len += (gsize) (_tmp17_ * (i - 1));
		_tmp18_ = g_malloc (len);
		res = _tmp18_;
		_tmp20_ = str_array[0];
		if (_tmp20_ != NULL) {
			const gchar* _tmp21_;
			_tmp21_ = str_array[0];
			_tmp19_ = (const gchar*) _tmp21_;
		} else {
			_tmp19_ = "";
		}
		_tmp22_ = res;
		_tmp23_ = g_stpcpy ((void*) _tmp22_, _tmp19_);
		ptr = _tmp23_;
		{
			gboolean _tmp24_ = FALSE;
			i = 1;
			_tmp24_ = TRUE;
			while (TRUE) {
				void* _tmp26_;
				void* _tmp27_;
				const gchar* _tmp28_ = NULL;
				const gchar* _tmp29_;
				void* _tmp31_;
				void* _tmp32_;
				if (!_tmp24_) {
					gint _tmp25_;
					_tmp25_ = i;
					i = _tmp25_ + 1;
				}
				_tmp24_ = FALSE;
				if (!(i < str_array_length1)) {
					break;
				}
				_tmp26_ = ptr;
				_tmp27_ = g_stpcpy (_tmp26_, (const gchar*) separator);
				ptr = _tmp27_;
				_tmp29_ = str_array[i];
				if (_tmp29_ != NULL) {
					const gchar* _tmp30_;
					_tmp30_ = str_array[i];
					_tmp28_ = (const gchar*) _tmp30_;
				} else {
					_tmp28_ = "";
				}
				_tmp31_ = ptr;
				_tmp32_ = g_stpcpy (_tmp31_, _tmp28_);
				ptr = _tmp32_;
			}
		}
		_tmp33_ = res;
		res = NULL;
		result = (gchar*) _tmp33_;
		return result;
	} else {
		gchar* _tmp34_;
		_tmp34_ = g_strdup ("");
		result = _tmp34_;
		return result;
	}
}

TubaWidgetsAccount*
tuba_widgets_account_construct (GType object_type,
                                TubaAPIAccount* account)
{
	TubaWidgetsAccount * self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	TubaWidgetsBackground* _tmp3_;
	TubaWidgetsAvatar* _tmp4_;
	TubaSettings* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	TubaSettings* _tmp9_;
	TubaWidgetsEmojiLabel* _tmp10_;
	GeeHashMap* _tmp11_;
	GeeHashMap* _tmp12_;
	GeeHashMap* _tmp13_;
	TubaWidgetsEmojiLabel* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	GtkLabel* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	TubaWidgetsAvatar* _tmp21_;
	gboolean _tmp22_ = FALSE;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	TubaWidgetsMarkupView* _tmp30_;
	GRegex* _tmp31_;
	GRegex* _tmp32_;
	TubaWidgetsMarkupView* _tmp33_;
	GeeHashMap* _tmp34_;
	GeeHashMap* _tmp35_;
	GeeHashMap* _tmp36_;
	TubaWidgetsMarkupView* _tmp37_;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	GtkImage* _tmp40_;
	gboolean _tmp41_;
	gboolean _tmp42_;
	TubaWidgetsAccountRelationshipButton* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	TubaAPIRelationship* _tmp47_;
	TubaAPIRelationship* _tmp48_;
	TubaAPIAccount* _tmp51_;
	const gchar* _tmp52_;
	const gchar* _tmp53_;
	gchar** stats = NULL;
	gchar** _tmp68_;
	gint stats_length1;
	gint _stats_size_;
	gint64 _tmp82_;
	gint64 _tmp83_;
	gint64 _tmp97_;
	gint64 _tmp98_;
	GtkLabel* _tmp109_;
	gchar** _tmp110_;
	gint _tmp110__length1;
	gchar* _tmp111_;
	gchar* _tmp112_;
	g_return_val_if_fail (account != NULL, NULL);
	self = (TubaWidgetsAccount*) g_object_new (object_type, NULL);
	_tmp0_ = tuba_api_account_get_id (account);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (self->priv->account_id);
	self->priv->account_id = _tmp2_;
	g_signal_connect_object (self, "open", (GCallback) _tuba_widgetizable_open_tuba_widgets_account_open, (TubaWidgetizable*) account, 0);
	_tmp3_ = self->priv->background;
	g_signal_connect_object ((GtkButton*) _tmp3_, "clicked", (GCallback) _tuba_widgetizable_open_gtk_button_clicked, (TubaWidgetizable*) account, 0);
	_tmp4_ = self->priv->avatar;
	g_signal_connect_object ((GtkButton*) _tmp4_, "clicked", (GCallback) _tuba_widgetizable_open_gtk_button_clicked, (TubaWidgetizable*) account, 0);
	_tmp5_ = tuba_settings;
	_tmp6_ = tuba_settings_get_scale_emoji_hover (_tmp5_);
	_tmp7_ = _tmp6_;
	if (_tmp7_) {
		TubaWidgetsMarkupView* _tmp8_;
		_tmp8_ = self->priv->note;
		gtk_widget_add_css_class ((GtkWidget*) _tmp8_, "lww-scale-emoji-hover");
	}
	_tmp9_ = tuba_settings;
	g_signal_connect_object ((GObject*) _tmp9_, "notify::scale-emoji-hover", (GCallback) _tuba_widgets_account_toggle_scale_emoji_hover_g_object_notify, self, 0);
	_tmp10_ = self->priv->display_name;
	_tmp11_ = tuba_api_account_get_emojis_map (account);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_;
	tuba_widgets_emoji_label_set_instance_emojis (_tmp10_, _tmp13_);
	_g_object_unref0 (_tmp13_);
	_tmp14_ = self->priv->display_name;
	_tmp15_ = tuba_api_account_get_display_name (account);
	_tmp16_ = _tmp15_;
	tuba_widgets_emoji_label_set_content (_tmp14_, _tmp16_);
	_tmp17_ = self->priv->handle;
	_tmp18_ = tuba_api_account_get_handle (account);
	_tmp19_ = _tmp18_;
	_tmp20_ = _tmp19_;
	gtk_label_set_label (_tmp17_, _tmp20_);
	_g_free0 (_tmp20_);
	_tmp21_ = self->priv->avatar;
	tuba_widgets_avatar_set_account (_tmp21_, account);
	_tmp23_ = tuba_api_account_get_avatar_description (account);
	_tmp24_ = _tmp23_;
	if (_tmp24_ != NULL) {
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		_tmp25_ = tuba_api_account_get_avatar_description (account);
		_tmp26_ = _tmp25_;
		_tmp22_ = g_strcmp0 (_tmp26_, "") != 0;
	} else {
		_tmp22_ = FALSE;
	}
	if (_tmp22_) {
		TubaWidgetsAvatar* _tmp27_;
		const gchar* _tmp28_;
		const gchar* _tmp29_;
		_tmp27_ = self->priv->avatar;
		_tmp28_ = tuba_api_account_get_avatar_description (account);
		_tmp29_ = _tmp28_;
		tuba_widgets_avatar_set_alternative_text (_tmp27_, _tmp29_);
	}
	_tmp30_ = self->priv->note;
	_tmp31_ = tuba_api_search_result_get_tuba_search_query_regex ((TubaAPISearchResult*) account);
	_tmp32_ = _tmp31_;
	tuba_widgets_markup_view_set_bold_text_regex (_tmp30_, _tmp32_);
	_tmp33_ = self->priv->note;
	_tmp34_ = tuba_api_account_get_emojis_map (account);
	_tmp35_ = _tmp34_;
	_tmp36_ = _tmp35_;
	tuba_widgets_markup_view_set_instance_emojis (_tmp33_, _tmp36_);
	_g_object_unref0 (_tmp36_);
	_tmp37_ = self->priv->note;
	_tmp38_ = tuba_api_account_get_note (account);
	_tmp39_ = _tmp38_;
	tuba_widgets_markup_view_set_content (_tmp37_, _tmp39_);
	_tmp40_ = self->priv->cover_bot_badge;
	_tmp41_ = tuba_api_account_get_bot (account);
	_tmp42_ = _tmp41_;
	gtk_widget_set_visible ((GtkWidget*) _tmp40_, _tmp42_);
	_tmp43_ = self->priv->rsbtn;
	_tmp44_ = tuba_api_account_get_handle (account);
	_tmp45_ = _tmp44_;
	_tmp46_ = _tmp45_;
	tuba_widgets_relationship_button_set_handle ((TubaWidgetsRelationshipButton*) _tmp43_, _tmp46_);
	_g_free0 (_tmp46_);
	_tmp47_ = tuba_api_account_get_tuba_rs (account);
	_tmp48_ = _tmp47_;
	if (_tmp48_ != NULL) {
		TubaAPIRelationship* _tmp49_;
		TubaAPIRelationship* _tmp50_;
		_tmp49_ = tuba_api_account_get_tuba_rs (account);
		_tmp50_ = _tmp49_;
		tuba_widgets_account_set_rs (self, _tmp50_);
	}
	tuba_widgets_account_set_api_account (self, account);
	_tmp51_ = self->priv->_api_account;
	g_signal_connect_object ((GObject*) _tmp51_, "notify::tuba-rs", (GCallback) _tuba_widgets_account_on_tuba_rs_g_object_notify, self, 0);
	_tmp52_ = tuba_api_account_get_header (account);
	_tmp53_ = _tmp52_;
	if (string_contains (_tmp53_, "/headers/original/missing.png")) {
		TubaWidgetsBackground* _tmp54_;
		TubaWidgetsAvatar* _tmp55_;
		GdkPaintable* _tmp56_;
		GdkPaintable* _tmp57_;
		_tmp54_ = self->priv->background;
		_tmp55_ = self->priv->avatar;
		_tmp56_ = tuba_widgets_avatar_get_custom_image (_tmp55_);
		_tmp57_ = _tmp56_;
		tuba_widgets_background_set_paintable (_tmp54_, _tmp57_);
	} else {
		const gchar* _tmp58_;
		const gchar* _tmp59_;
		gboolean _tmp60_ = FALSE;
		const gchar* _tmp61_;
		const gchar* _tmp62_;
		_tmp58_ = tuba_api_account_get_header (account);
		_tmp59_ = _tmp58_;
		tuba_helper_image_request_paintable (_tmp59_, NULL, FALSE, _tuba_widgets_account_on_cache_response_tuba_helper_image_on_item_changed_fn, g_object_ref (self), g_object_unref, NULL);
		_tmp61_ = tuba_api_account_get_header_description (account);
		_tmp62_ = _tmp61_;
		if (_tmp62_ != NULL) {
			const gchar* _tmp63_;
			const gchar* _tmp64_;
			_tmp63_ = tuba_api_account_get_header_description (account);
			_tmp64_ = _tmp63_;
			_tmp60_ = g_strcmp0 (_tmp64_, "") != 0;
		} else {
			_tmp60_ = FALSE;
		}
		if (_tmp60_) {
			TubaWidgetsBackground* _tmp65_;
			const gchar* _tmp66_;
			const gchar* _tmp67_;
			_tmp65_ = self->priv->background;
			_tmp66_ = tuba_api_account_get_header_description (account);
			_tmp67_ = _tmp66_;
			tuba_widgets_background_set_alternative_text (_tmp65_, _tmp67_);
		}
	}
	_tmp68_ = g_new0 (gchar*, 0 + 1);
	stats = _tmp68_;
	stats_length1 = 0;
	_stats_size_ = stats_length1;
	{
		gchar* posts_str = NULL;
		gint64 _tmp69_;
		gint64 _tmp70_;
		gint64 _tmp71_;
		gint64 _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		const gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
		gchar* _tmp79_;
		const gchar* _tmp80_;
		gchar* _tmp81_;
		_tmp69_ = tuba_api_account_get_statuses_count (account);
		_tmp70_ = _tmp69_;
		_tmp71_ = tuba_api_account_get_statuses_count (account);
		_tmp72_ = _tmp71_;
		_tmp73_ = tuba_utils_units_shorten (_tmp72_);
		_tmp74_ = _tmp73_;
		_tmp75_ = string_to_string (_tmp74_);
		_tmp76_ = g_strconcat ("<b>", _tmp75_, "</b>", NULL);
		_tmp77_ = _tmp76_;
		_tmp78_ = g_strdup_printf (ngettext ("%s Post", "%s Posts", (gulong) _tmp70_), _tmp77_);
		_tmp79_ = _tmp78_;
		_g_free0 (_tmp77_);
		_g_free0 (_tmp74_);
		posts_str = _tmp79_;
		_tmp80_ = posts_str;
		_tmp81_ = g_strdup_printf ("<span allow_breaks=\"false\">%s</span>", _tmp80_);
		_vala_array_add129 (&stats, &stats_length1, &_stats_size_, _tmp81_);
		_g_free0 (posts_str);
	}
	_tmp82_ = tuba_api_account_get_followers_count (account);
	_tmp83_ = _tmp82_;
	if (_tmp83_ >= ((gint64) 0)) {
		gchar* followers_str = NULL;
		gint64 _tmp84_;
		gint64 _tmp85_;
		gint64 _tmp86_;
		gint64 _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		const gchar* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		gchar* _tmp94_;
		const gchar* _tmp95_;
		gchar* _tmp96_;
		_tmp84_ = tuba_api_account_get_statuses_count (account);
		_tmp85_ = _tmp84_;
		_tmp86_ = tuba_api_account_get_followers_count (account);
		_tmp87_ = _tmp86_;
		_tmp88_ = tuba_utils_units_shorten (_tmp87_);
		_tmp89_ = _tmp88_;
		_tmp90_ = string_to_string (_tmp89_);
		_tmp91_ = g_strconcat ("<b>", _tmp90_, "</b>", NULL);
		_tmp92_ = _tmp91_;
		_tmp93_ = g_strdup_printf (ngettext ("%s Follower", "%s Followers", (gulong) _tmp85_), _tmp92_);
		_tmp94_ = _tmp93_;
		_g_free0 (_tmp92_);
		_g_free0 (_tmp89_);
		followers_str = _tmp94_;
		_tmp95_ = followers_str;
		_tmp96_ = g_strdup_printf ("<span allow_breaks=\"false\">%s</span>", _tmp95_);
		_vala_array_add130 (&stats, &stats_length1, &_stats_size_, _tmp96_);
		_g_free0 (followers_str);
	}
	_tmp97_ = tuba_api_account_get_following_count (account);
	_tmp98_ = _tmp97_;
	if (_tmp98_ >= ((gint64) 0)) {
		gint64 _tmp99_;
		gint64 _tmp100_;
		gchar* _tmp101_;
		gchar* _tmp102_;
		const gchar* _tmp103_;
		gchar* _tmp104_;
		gchar* _tmp105_;
		gchar* _tmp106_;
		gchar* _tmp107_;
		gchar* _tmp108_;
		_tmp99_ = tuba_api_account_get_following_count (account);
		_tmp100_ = _tmp99_;
		_tmp101_ = tuba_utils_units_shorten (_tmp100_);
		_tmp102_ = _tmp101_;
		_tmp103_ = string_to_string (_tmp102_);
		_tmp104_ = g_strconcat ("<b>", _tmp103_, "</b>", NULL);
		_tmp105_ = _tmp104_;
		_tmp106_ = g_strdup_printf (_ ("%s Following"), _tmp105_);
		_tmp107_ = _tmp106_;
		_tmp108_ = g_strdup_printf ("<span allow_breaks=\"false\">%s</span>", _tmp107_);
		_vala_array_add131 (&stats, &stats_length1, &_stats_size_, _tmp108_);
		_g_free0 (_tmp107_);
		_g_free0 (_tmp105_);
		_g_free0 (_tmp102_);
	}
	_tmp109_ = self->priv->stats_label;
	_tmp110_ = stats;
	_tmp110__length1 = stats_length1;
	_tmp111_ = _vala_g_strjoinv ("   ", _tmp110_, (gint) _tmp110__length1);
	_tmp112_ = _tmp111_;
	gtk_label_set_label (_tmp109_, _tmp112_);
	_g_free0 (_tmp112_);
	tuba_widgets_account_update_aria (self);
	stats = (_vala_array_free (stats, stats_length1, (GDestroyNotify) g_free), NULL);
	return self;
}

TubaWidgetsAccount*
tuba_widgets_account_new (TubaAPIAccount* account)
{
	return tuba_widgets_account_construct (TUBA_WIDGETS_TYPE_ACCOUNT, account);
}

static void
tuba_widgets_account_on_tuba_rs (TubaWidgetsAccount* self)
{
	gboolean _tmp0_ = FALSE;
	TubaAPIAccount* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->_api_account;
	if (_tmp1_ != NULL) {
		TubaAPIAccount* _tmp2_;
		TubaAPIRelationship* _tmp3_;
		TubaAPIRelationship* _tmp4_;
		_tmp2_ = self->priv->_api_account;
		_tmp3_ = tuba_api_account_get_tuba_rs (_tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIAccount* _tmp5_;
		TubaAPIRelationship* _tmp6_;
		TubaAPIRelationship* _tmp7_;
		_tmp5_ = self->priv->_api_account;
		_tmp6_ = tuba_api_account_get_tuba_rs (_tmp5_);
		_tmp7_ = _tmp6_;
		tuba_widgets_account_set_rs (self, _tmp7_);
	}
}

TubaWidgetsFollowRequestRow*
tuba_widgets_account_add_fr_row (TubaWidgetsAccount* self)
{
	TubaWidgetsFollowRequestRow* fr_row = NULL;
	const gchar* _tmp0_;
	TubaWidgetsFollowRequestRow* _tmp1_ = NULL;
	GtkGrid* _tmp2_;
	TubaWidgetsFollowRequestRow* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->account_id;
	_tmp1_ = tuba_widgets_follow_request_row_new (_tmp0_);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp1_, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp1_, 6);
	g_object_ref_sink (_tmp1_);
	fr_row = _tmp1_;
	_tmp2_ = self->priv->grid;
	gtk_grid_attach (_tmp2_, (GtkWidget*) fr_row, 0, 5, 2, 1);
	result = fr_row;
	return result;
}

void
tuba_widgets_account_set_disable_profile_open (TubaWidgetsAccount* self,
                                               gboolean value)
{
	g_return_if_fail (self != NULL);
	if (value == TRUE) {
		GtkGrid* _tmp0_;
		GtkGrid* _tmp1_;
		GtkGrid* _tmp2_;
		gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, FALSE);
		_tmp0_ = self->priv->grid;
		gtk_widget_set_can_focus ((GtkWidget*) _tmp0_, FALSE);
		_tmp1_ = self->priv->grid;
		gtk_widget_set_focusable ((GtkWidget*) _tmp1_, FALSE);
		_tmp2_ = self->priv->grid;
		gtk_widget_set_can_target ((GtkWidget*) _tmp2_, FALSE);
		if (self->priv->open_signal != ((gulong) 0)) {
			g_signal_handler_disconnect ((GObject*) self, self->priv->open_signal);
		}
	}
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_DISABLE_PROFILE_OPEN_PROPERTY]);
}

static void
_tuba_widgets_account_on_rs_invalidate_tuba_api_relationship_invalidated (TubaAPIRelationship* _sender,
                                                                          gpointer self)
{
	tuba_widgets_account_on_rs_invalidate ((TubaWidgetsAccount*) self);
}

void
tuba_widgets_account_set_rs (TubaWidgetsAccount* self,
                             TubaAPIRelationship* value)
{
	TubaWidgetsAccountRelationshipButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->rsbtn;
	tuba_widgets_relationship_button_set_rs ((TubaWidgetsRelationshipButton*) _tmp0_, value);
	_tmp1_ = tuba_api_relationship_get_tuba_has_loaded (value);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		TubaWidgetsAccountRelationshipButton* _tmp3_;
		TubaAPIRelationship* _tmp4_;
		TubaAPIRelationship* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		_tmp3_ = self->priv->rsbtn;
		_tmp4_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) _tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = tuba_api_relationship_to_string (_tmp5_);
		_tmp7_ = _tmp6_;
		tuba_widgets_account_set_cover_badge_label (self, _tmp7_);
		_g_free0 (_tmp7_);
	} else {
		TubaWidgetsAccountRelationshipButton* _tmp8_;
		TubaAPIRelationship* _tmp9_;
		TubaAPIRelationship* _tmp10_;
		gulong _tmp11_;
		_tmp8_ = self->priv->rsbtn;
		_tmp9_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) _tmp8_);
		_tmp10_ = _tmp9_;
		_tmp11_ = g_signal_connect_object (_tmp10_, "invalidated", (GCallback) _tuba_widgets_account_on_rs_invalidate_tuba_api_relationship_invalidated, self, 0);
		self->priv->invalidate_signal_id = _tmp11_;
	}
	tuba_widgets_account_update_aria (self);
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_RS_PROPERTY]);
}

void
tuba_widgets_account_set_additional_label (TubaWidgetsAccount* self,
                                           const gchar* value)
{
	GtkOverlay* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar** _tmp5_;
	GtkLabel* _tmp6_ = NULL;
	GtkLabel* _tmp7_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->cover_overlay;
	_tmp1_ = g_strdup ("cover-badge");
	_tmp2_ = g_strdup ("osd");
	_tmp3_ = g_strdup ("badge");
	_tmp4_ = g_strdup ("heading");
	_tmp5_ = g_new0 (gchar*, 4 + 1);
	_tmp5_[0] = _tmp1_;
	_tmp5_[1] = _tmp2_;
	_tmp5_[2] = _tmp3_;
	_tmp5_[3] = _tmp4_;
	_tmp6_ = (GtkLabel*) gtk_label_new (value);
	gtk_label_set_xalign (_tmp6_, 0.0f);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp6_, _tmp5_);
	_tmp5_ = (_vala_array_free (_tmp5_, 4, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_halign ((GtkWidget*) _tmp6_, GTK_ALIGN_START);
	gtk_widget_set_valign ((GtkWidget*) _tmp6_, GTK_ALIGN_START);
	g_object_ref_sink (_tmp6_);
	_tmp7_ = _tmp6_;
	gtk_overlay_add_overlay (_tmp0_, (GtkWidget*) _tmp7_);
	_g_object_unref0 (_tmp7_);
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_ADDITIONAL_LABEL_PROPERTY]);
}

const gchar*
tuba_widgets_account_get_cover_badge_label (TubaWidgetsAccount* self)
{
	const gchar* result;
	GtkLabel* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->cover_badge;
	_tmp1_ = gtk_label_get_label (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_widgets_account_set_cover_badge_label (TubaWidgetsAccount* self,
                                            const gchar* value)
{
	gboolean has_label = FALSE;
	GtkLabel* _tmp0_;
	GtkLabel* _tmp1_;
	g_return_if_fail (self != NULL);
	has_label = g_strcmp0 (value, "") != 0;
	_tmp0_ = self->priv->cover_badge;
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, has_label);
	_tmp1_ = self->priv->cover_badge;
	gtk_label_set_label (_tmp1_, value);
	tuba_widgets_account_update_cover_badge (self);
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_COVER_BADGE_LABEL_PROPERTY]);
}

gboolean
tuba_widgets_account_get_is_bot (TubaWidgetsAccount* self)
{
	gboolean result;
	GtkImage* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->cover_bot_badge;
	_tmp1_ = gtk_widget_get_visible ((GtkWidget*) _tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_widgets_account_set_is_bot (TubaWidgetsAccount* self,
                                 gboolean value)
{
	GtkImage* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->cover_bot_badge;
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, value);
	tuba_widgets_account_update_cover_badge (self);
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_IS_BOT_PROPERTY]);
}

static TubaAPIAccount*
tuba_widgets_account_get_api_account (TubaWidgetsAccount* self)
{
	TubaAPIAccount* result;
	TubaAPIAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_api_account;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_widgets_account_set_api_account (TubaWidgetsAccount* self,
                                      TubaAPIAccount* value)
{
	TubaAPIAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = _g_object_ref0 (value);
	_g_object_unref0 (self->priv->_api_account);
	self->priv->_api_account = _tmp0_;
}

static void
tuba_widgets_account_relationship_button_on_relationship_invalidated_global (TubaWidgetsAccountRelationshipButton* self,
                                                                             TubaAPIRelationship* new_relationship)
{
	gboolean _tmp0_ = FALSE;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (new_relationship != NULL);
	_tmp1_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) self);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == NULL) {
		_tmp0_ = TRUE;
	} else {
		TubaAPIRelationship* _tmp3_;
		TubaAPIRelationship* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		_tmp3_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) self);
		_tmp4_ = _tmp3_;
		_tmp5_ = tuba_api_relationship_get_id (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = tuba_api_relationship_get_id (new_relationship);
		_tmp8_ = _tmp7_;
		_tmp0_ = g_strcmp0 (_tmp6_, _tmp8_) != 0;
	}
	if (_tmp0_) {
		return;
	}
	tuba_widgets_relationship_button_set_rs ((TubaWidgetsRelationshipButton*) self, new_relationship);
}

static void
tuba_widgets_account_relationship_button_real_invalidate (TubaWidgetsRelationshipButton* base)
{
	TubaWidgetsAccountRelationshipButton * self;
	gboolean _tmp0_ = FALSE;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	self = (TubaWidgetsAccountRelationshipButton*) base;
	_tmp1_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) self);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == NULL) {
		_tmp0_ = TRUE;
	} else {
		TubaAPIRelationship* _tmp3_;
		TubaAPIRelationship* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
		_tmp3_ = tuba_widgets_relationship_button_get_rs ((TubaWidgetsRelationshipButton*) self);
		_tmp4_ = _tmp3_;
		_tmp5_ = tuba_api_relationship_get_domain_blocking (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp0_ = _tmp6_;
	}
	if (_tmp0_) {
		gtk_widget_set_visible ((GtkWidget*) self, FALSE);
		return;
	}
	gtk_widget_set_visible ((GtkWidget*) self, TRUE);
	TUBA_WIDGETS_RELATIONSHIP_BUTTON_CLASS (tuba_widgets_account_relationship_button_parent_class)->invalidate (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButton));
}

TubaWidgetsAccountRelationshipButton*
tuba_widgets_account_relationship_button_construct (GType object_type)
{
	TubaWidgetsAccountRelationshipButton * self = NULL;
	self = (TubaWidgetsAccountRelationshipButton*) tuba_widgets_relationship_button_construct (object_type);
	return self;
}

TubaWidgetsAccountRelationshipButton*
tuba_widgets_account_relationship_button_new (void)
{
	return tuba_widgets_account_relationship_button_construct (TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON);
}

static void
_tuba_widgets_account_relationship_button_on_relationship_invalidated_global_tuba_application_relationship_invalidated (TubaApplication* _sender,
                                                                                                                        TubaAPIRelationship* new_relationship,
                                                                                                                        gpointer self)
{
	tuba_widgets_account_relationship_button_on_relationship_invalidated_global ((TubaWidgetsAccountRelationshipButton*) self, new_relationship);
}

static GObject *
tuba_widgets_account_relationship_button_constructor (GType type,
                                                      guint n_construct_properties,
                                                      GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaWidgetsAccountRelationshipButton * self;
	TubaApplication* _tmp0_;
	parent_class = G_OBJECT_CLASS (tuba_widgets_account_relationship_button_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsAccountRelationshipButton);
	_tmp0_ = tuba_app;
	g_signal_connect_object (_tmp0_, "relationship-invalidated", (GCallback) _tuba_widgets_account_relationship_button_on_relationship_invalidated_global_tuba_application_relationship_invalidated, self, 0);
	return obj;
}

static void
tuba_widgets_account_relationship_button_class_init (TubaWidgetsAccountRelationshipButtonClass * klass,
                                                     gpointer klass_data)
{
	tuba_widgets_account_relationship_button_parent_class = g_type_class_peek_parent (klass);
	((TubaWidgetsRelationshipButtonClass *) klass)->invalidate = (void (*) (TubaWidgetsRelationshipButton*)) tuba_widgets_account_relationship_button_real_invalidate;
	G_OBJECT_CLASS (klass)->constructor = tuba_widgets_account_relationship_button_constructor;
}

static void
tuba_widgets_account_relationship_button_instance_init (TubaWidgetsAccountRelationshipButton * self,
                                                        gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_account_relationship_button_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAccountRelationshipButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_account_relationship_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAccountRelationshipButton), 0, (GInstanceInitFunc) tuba_widgets_account_relationship_button_instance_init, NULL };
	GType tuba_widgets_account_relationship_button_type_id;
	tuba_widgets_account_relationship_button_type_id = g_type_register_static (TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, "TubaWidgetsAccountRelationshipButton", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_widgets_account_relationship_button_type_id;
}

GType
tuba_widgets_account_relationship_button_get_type (void)
{
	static GType tuba_widgets_account_relationship_button_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_account_relationship_button_type_id__once)) {
		GType tuba_widgets_account_relationship_button_type_id;
		tuba_widgets_account_relationship_button_type_id = tuba_widgets_account_relationship_button_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_account_relationship_button_type_id__once, tuba_widgets_account_relationship_button_type_id);
	}
	return tuba_widgets_account_relationship_button_type_id__once;
}

static void
tuba_widgets_account_class_init (TubaWidgetsAccountClass * klass,
                                 gpointer klass_data)
{
	tuba_widgets_account_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsAccount_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_widgets_account_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_widgets_account_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_account_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_ACCOUNT_DISABLE_PROFILE_OPEN_PROPERTY, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_DISABLE_PROFILE_OPEN_PROPERTY] = g_param_spec_boolean ("disable-profile-open", "disable-profile-open", "disable-profile-open", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_ACCOUNT_RS_PROPERTY, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_RS_PROPERTY] = g_param_spec_object ("rs", "rs", "rs", TUBA_API_TYPE_RELATIONSHIP, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_ACCOUNT_ADDITIONAL_LABEL_PROPERTY, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_ADDITIONAL_LABEL_PROPERTY] = g_param_spec_string ("additional-label", "additional-label", "additional-label", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_ACCOUNT_COVER_BADGE_LABEL_PROPERTY, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_COVER_BADGE_LABEL_PROPERTY] = g_param_spec_string ("cover-badge-label", "cover-badge-label", "cover-badge-label", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_ACCOUNT_IS_BOT_PROPERTY, tuba_widgets_account_properties[TUBA_WIDGETS_ACCOUNT_IS_BOT_PROPERTY] = g_param_spec_boolean ("is-bot", "is-bot", "is-bot", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/dev/geopjr/Tuba/ui/widgets/profile.ui");
	tuba_widgets_account_signals[TUBA_WIDGETS_ACCOUNT_OPEN_SIGNAL] = g_signal_new ("open", TUBA_WIDGETS_TYPE_ACCOUNT, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "background", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, background));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cover_overlay", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, cover_overlay));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cover_badge", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, cover_badge));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cover_bot_badge", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, cover_bot_badge));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cover_badge_box", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, cover_badge_box));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "display_name", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, display_name));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "handle", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, handle));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "stats_label", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, stats_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "avatar", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, avatar));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "note", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, note));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "rsbtn", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, rsbtn));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "grid", FALSE, TubaWidgetsAccount_private_offset + G_STRUCT_OFFSET (TubaWidgetsAccountPrivate, grid));
	g_type_ensure (TUBA_WIDGETS_TYPE_BACKGROUND);
	g_type_ensure (TUBA_WIDGETS_TYPE_AVATAR);
	g_type_ensure (TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON);
	g_type_ensure (TUBA_WIDGETS_TYPE_EMOJI_LABEL);
	g_type_ensure (TUBA_WIDGETS_TYPE_MARKUP_VIEW);
}

static void
tuba_widgets_account_instance_init (TubaWidgetsAccount * self,
                                    gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_widgets_account_get_instance_private (self);
	self->priv->invalidate_signal_id = (gulong) 0;
	_tmp0_ = g_strdup ("");
	self->priv->account_id = _tmp0_;
	self->priv->open_signal = (gulong) 0;
	g_type_ensure (TUBA_WIDGETS_TYPE_BACKGROUND);
	g_type_ensure (TUBA_WIDGETS_TYPE_EMOJI_LABEL);
	g_type_ensure (TUBA_WIDGETS_TYPE_AVATAR);
	g_type_ensure (TUBA_WIDGETS_TYPE_MARKUP_VIEW);
	g_type_ensure (TUBA_WIDGETS_ACCOUNT_TYPE_RELATIONSHIP_BUTTON);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
tuba_widgets_account_finalize (GObject * obj)
{
	TubaWidgetsAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount);
	g_debug ("Account.vala:4: Destroying Widgets.Account");
	_g_object_unref0 (self->priv->_api_account);
	_g_free0 (self->priv->account_id);
	G_OBJECT_CLASS (tuba_widgets_account_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_account_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAccountClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_account_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAccount), 0, (GInstanceInitFunc) tuba_widgets_account_instance_init, NULL };
	GType tuba_widgets_account_type_id;
	tuba_widgets_account_type_id = g_type_register_static (gtk_list_box_row_get_type (), "TubaWidgetsAccount", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsAccount_private_offset = g_type_add_instance_private (tuba_widgets_account_type_id, sizeof (TubaWidgetsAccountPrivate));
	return tuba_widgets_account_type_id;
}

GType
tuba_widgets_account_get_type (void)
{
	static GType tuba_widgets_account_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_account_type_id__once)) {
		GType tuba_widgets_account_type_id;
		tuba_widgets_account_type_id = tuba_widgets_account_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_account_type_id__once, tuba_widgets_account_type_id);
	}
	return tuba_widgets_account_type_id__once;
}

static void
_vala_tuba_widgets_account_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec)
{
	TubaWidgetsAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount);
	switch (property_id) {
		case TUBA_WIDGETS_ACCOUNT_COVER_BADGE_LABEL_PROPERTY:
		g_value_set_string (value, tuba_widgets_account_get_cover_badge_label (self));
		break;
		case TUBA_WIDGETS_ACCOUNT_IS_BOT_PROPERTY:
		g_value_set_boolean (value, tuba_widgets_account_get_is_bot (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_widgets_account_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec)
{
	TubaWidgetsAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount);
	switch (property_id) {
		case TUBA_WIDGETS_ACCOUNT_DISABLE_PROFILE_OPEN_PROPERTY:
		tuba_widgets_account_set_disable_profile_open (self, g_value_get_boolean (value));
		break;
		case TUBA_WIDGETS_ACCOUNT_RS_PROPERTY:
		tuba_widgets_account_set_rs (self, g_value_get_object (value));
		break;
		case TUBA_WIDGETS_ACCOUNT_ADDITIONAL_LABEL_PROPERTY:
		tuba_widgets_account_set_additional_label (self, g_value_get_string (value));
		break;
		case TUBA_WIDGETS_ACCOUNT_COVER_BADGE_LABEL_PROPERTY:
		tuba_widgets_account_set_cover_badge_label (self, g_value_get_string (value));
		break;
		case TUBA_WIDGETS_ACCOUNT_IS_BOT_PROPERTY:
		tuba_widgets_account_set_is_bot (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

